@@ -75,6 +75,7 @@
 
 #   include <netinet/in.h>
 #   include <stdio.h>
+#   include <stdbool.h>
 #   ifdef __linux__
 #      include <linux/limits.h>
 #      include <sys/socket.h>
@@ -89,8 +90,10 @@
 
 #   if defined(__GNUC__)
 #      define PURE_FUNCTION __attribute__((pure))
+#      define PRINTF_FORMAT(a,b) __attribute__ ((format (printf, a, b)))
 #   else
 #      define PURE_FUNCTION /* nothing */
+#      define PRINTF_FORMAT(a,b) /* nothing */
 #   endif
 
 #   if !defined (__WIN32__) && !defined(_MSC_VER)
@@ -239,13 +242,9 @@ enum {
 #      define __func__ __FUNCTION__
 #   endif
 
-#   define PRINT_FUNCTION_VERBOSE(_verbose)  \
-    { \
-        if (_verbose) \
-        { \
-            dlt_vlog(LOG_INFO, "%s()\n", __func__); \
-        } \
-    }
+#   define PRINT_FUNCTION_VERBOSE(_verbose) \
+    if (_verbose) \
+        dlt_vlog(LOG_INFO, "%s()\n", __func__)
 
 #   ifndef NULL
 #      define NULL (char *)0
@@ -296,44 +295,44 @@ enum {
 #   define DLT_FILTER_MAX 30 /**< Maximum number of filters */
 
 #   define DLT_MSG_READ_VALUE(dst, src, length, type) \
-    { \
-        if ((length < 0) || ((length) < ((int32_t) sizeof(type)))) \
+    do { \
+        if ((length < 0) || ((length) < ((int32_t)sizeof(type)))) \
         { length = -1; } \
         else \
-        { dst = *((type *)src); src += sizeof(type); length -= (int32_t) sizeof(type); } \
-    }
+        { dst = *((type *)src); src += sizeof(type); length -= sizeof(type); } \
+    } while(0)
 
 #   define DLT_MSG_READ_ID(dst, src, length) \
-    { \
+    do { \
         if ((length < 0) || ((length) < DLT_ID_SIZE)) \
         { length = -1; } \
         else \
         { memcpy(dst, src, DLT_ID_SIZE); src += DLT_ID_SIZE; length -= DLT_ID_SIZE; } \
-    }
+    } while(0)
 
-#define DLT_MSG_READ_STRING(dst, src, maxlength, dstlength, length) \
-{ \
-    if ((maxlength < 0) || (length <= 0) || (dstlength < length) || (maxlength < length)) \
-    { \
-        maxlength = -1; \
-    } \
-    else \
-    { \
-        memcpy(dst, src, (size_t) length); \
-        dlt_clean_string(dst, length); \
-        dst[length] = 0; \
-        src += length; \
-        maxlength -= length; \
-    } \
-}
+#   define DLT_MSG_READ_STRING(dst, src, maxlength, dstlength, length) \
+    do { \
+        if ((maxlength < 0) || (length <= 0) || (dstlength < length) || (maxlength < length)) \
+        { \
+            maxlength = -1; \
+        } \
+        else \
+        { \
+            memcpy(dst, src, length); \
+            dlt_clean_string(dst, length); \
+            dst[length] = 0; \
+            src += length; \
+            maxlength -= length; \
+        } \
+    } while(0)
 
 #   define DLT_MSG_READ_NULL(src, maxlength, length) \
-    { \
+    do { \
         if (((maxlength) < 0) || ((length) < 0) || ((maxlength) < (length))) \
         { length = -1; } \
         else \
         { src += length; maxlength -= length; } \
-    }
+    } while(0)
 
 #   define DLT_HEADER_SHOW_NONE       0x0000
 #   define DLT_HEADER_SHOW_TIME       0x0001
@@ -497,14 +496,14 @@ typedef struct sDltMessage
     int32_t resync_offset;
 
     /* size parameters */
-    uint32_t headersize;    /**< size of complete header including storage header */
-    uint32_t datasize;      /**< size of complete payload */
+    int32_t headersize;    /**< size of complete header including storage header */
+    int32_t datasize;      /**< size of complete payload */
 
     /* buffer for current loaded message */
     uint8_t headerbuffer[sizeof(DltStorageHeader) +
                          sizeof(DltStandardHeader) + sizeof(DltStandardHeaderExtra) + sizeof(DltExtendedHeader)]; /**< buffer for loading complete header */
     uint8_t *databuffer;         /**< buffer for loading payload */
-    uint32_t databuffersize;
+    int32_t databuffersize;
 
     /* header values of current loaded message */
     DltStorageHeader *storageheader;        /**< pointer to storage header of current loaded header */
@@ -733,6 +732,9 @@ typedef struct
 {
     char apid[DLT_FILTER_MAX][DLT_ID_SIZE]; /**< application id */
     char ctid[DLT_FILTER_MAX][DLT_ID_SIZE]; /**< context id */
+    int log_level[DLT_FILTER_MAX];          /**< log level */
+    int32_t payload_max[DLT_FILTER_MAX];        /**< upper border for payload */
+    int32_t payload_min[DLT_FILTER_MAX];        /**< lower border for payload */
     int counter;                            /**< number of filters */
 } DltFilter;
 
@@ -750,8 +752,8 @@ typedef struct sDltFile
     int32_t counter;       /**< number of messages in DLT file with filter */
     int32_t counter_total; /**< number of messages in DLT file without filter */
     int32_t position;      /**< current index to message parsed in DLT file starting at 0 */
-    long file_length;      /**< length of the file */
-    long file_position;    /**< current position in the file */
+    uint64_t file_length;    /**< length of the file */
+    uint64_t file_position;  /**< current position in the file */
 
     /* error counters */
     int32_t error_messages; /**< number of incomplete DLT messages found during file parsing */
@@ -775,12 +777,12 @@ typedef struct
     int32_t lastBytesRcvd;    /**< bytes received in last receive call */
     int32_t bytesRcvd;        /**< received bytes */
     int32_t totalBytesRcvd;   /**< total number of received bytes */
-    char *buffer;             /**< pointer to receiver buffer */
-    char *buf;                /**< pointer to position within receiver buffer */
-    char *backup_buf;         /** pointer to the buffer with partial messages if any **/
-    int fd;                   /**< connection handle */
+    char *buffer;         /**< pointer to receiver buffer */
+    char *buf;            /**< pointer to position within receiver buffer */
+    char *backup_buf;     /** pointer to the buffer with partial messages if any **/
+    int fd;               /**< connection handle */
     DltReceiverType type;     /**< type of connection handle */
-    uint32_t buffersize;      /**< size of receiver buffer */
+    int32_t buffersize;       /**< size of receiver buffer */
     struct sockaddr_in addr;  /**< socket address information */
 } DltReceiver;
 
@@ -872,7 +874,7 @@ DltReturnValue dlt_print_char_string(char **text, int textlength, uint8_t *ptr,
  * This function returns zero if @a str is a null pointer,
  * and it returns @a maxsize if the null character was not found in the first @a maxsize bytes of @a str.
  * This is a re-implementation of C11's strnlen_s, which we cannot yet assume to be available.
- * @param text pointer to string whose length is to be determined
+ * @param str pointer to string whose length is to be determined
  * @param maxsize maximal considered length of @a str
  * @return the bounded length of the string
  */
@@ -923,9 +925,9 @@ DltReturnValue dlt_filter_free(DltFilter *filter, int verbose);
  */
 DltReturnValue dlt_filter_load(DltFilter *filter, const char *filename, int verbose);
 /**
- * Save filter list to file.
+ * Save filter in space separated list to text file.
  * @param filter pointer to structure of organising DLT filter
- * @param filename filename to load filters from
+ * @param filename filename to safe filters into
  * @param verbose if set to true verbose information is printed out.
  * @return negative value if there was an error
  */
@@ -935,28 +937,40 @@ DltReturnValue dlt_filter_save(DltFilter *filter, const char *filename, int verb
  * @param filter pointer to structure of organising DLT filter
  * @param apid application id to be found in filter list
  * @param ctid context id to be found in filter list
+ * @param log_level log level to be found in filter list
+ * @param payload_min minimum payload lenght to be found in filter list
+ * @param payload_max maximum payload lenght to be found in filter list
  * @param verbose if set to true verbose information is printed out.
  * @return negative value if there was an error (or not found), else return index of filter
  */
-int dlt_filter_find(DltFilter *filter, const char *apid, const char *ctid, int verbose);
+int dlt_filter_find(DltFilter *filter, const char *apid, const char *ctid, const int log_level,
+                                const int32_t payload_min, const int32_t payload_max, int verbose);
 /**
  * Add new filter to filter list.
  * @param filter pointer to structure of organising DLT filter
  * @param apid application id to be added to filter list (must always be set).
  * @param ctid context id to be added to filter list. empty equals don't care.
+ * @param log_level log level to be added to filter list. 0 equals don't care.
+ * @param payload_min min lenght of payload to be added to filter list. 0 equals don't care.
+ * @param payload_max max lenght of payload to be added to filter list. INT32_MAX equals don't care.
  * @param verbose if set to true verbose information is printed out.
  * @return negative value if there was an error
  */
-DltReturnValue dlt_filter_add(DltFilter *filter, const char *apid, const char *ctid, int verbose);
+DltReturnValue dlt_filter_add(DltFilter *filter, const char *apid, const char *ctid, const int log_level,
+                                const int32_t payload_min, const int32_t payload_max, int verbose);
 /**
  * Delete filter from filter list
  * @param filter pointer to structure of organising DLT filter
  * @param apid application id to be deleted from filter list
  * @param ctid context id to be deleted from filter list
+ * @param log_level log level to be deleted from filter list
+ * @param payload_min minimum payload lenght to be deleted from filter list
+ * @param payload_max maximum payload lenght to be deleted from filter list
  * @param verbose if set to true verbose information is printed out.
  * @return negative value if there was an error
  */
-DltReturnValue dlt_filter_delete(DltFilter *filter, const char *apid, const char *ctid, int verbose);
+DltReturnValue dlt_filter_delete(DltFilter *filter, const char *apid, const char *ctid, const int log_level,
+                                const int32_t payload_min, const int32_t payload_max, int verbose);
 
 /**
  * Initialise the structure used to access a DLT message.
@@ -1170,6 +1184,13 @@ void dlt_log_set_fifo_basedir(const char *pipe_dir);
  * @param level the level
  */
 void dlt_log_set_level(int level);
+
+/**
+ * Set whether to print "name" and "unit" attributes in console output
+ * @param state  true = with attributes, false = without attributes
+ */
+void dlt_print_with_attributes(bool state);
+
 /**
  * Initialize (external) logging facility
  * @param mode positive, 0 = log to stdout, 1 = log to syslog, 2 = log to file, 3 = log to stderr
@@ -1180,7 +1201,7 @@ void dlt_log_init(int mode);
  * @param format format string for message
  * @return negative value if there was an error or the total number of characters written is returned on success
  */
-int dlt_user_printf(const char *format, ...);
+int dlt_user_printf(const char *format, ...) PRINTF_FORMAT(1, 2);
 /**
  * Log ASCII string with null-termination to (external) logging facility
  * @param prio priority (see syslog() call)
@@ -1194,7 +1215,7 @@ DltReturnValue dlt_log(int prio, char *s);
  * @param format format string for log message
  * @return negative value if there was an error
  */
-DltReturnValue dlt_vlog(int prio, const char *format, ...);
+DltReturnValue dlt_vlog(int prio, const char *format, ...) PRINTF_FORMAT(2, 3);
 /**
  * Log size bytes with variable arguments to (external) logging facility (similar to snprintf)
  * @param prio priority (see syslog() call)
@@ -1202,7 +1223,7 @@ DltReturnValue dlt_vlog(int prio, const char *format, ...);
  * @param format format string for log message
  * @return negative value if there was an error
  */
-DltReturnValue dlt_vnlog(int prio, size_t size, const char *format, ...);
+DltReturnValue dlt_vnlog(int prio, size_t size, const char *format, ...) PRINTF_FORMAT(3, 4);
 /**
  * De-Initialize (external) logging facility
  */
@@ -1291,7 +1312,7 @@ DltReturnValue dlt_check_storageheader(DltStorageHeader *storageheader);
  * @param required size
  * @return negative value if required size is not sufficient
  * */
-DltReturnValue dlt_check_rcv_data_size(uint32_t received, uint32_t required);
+DltReturnValue dlt_check_rcv_data_size(int received, int required);
 
 /**
  * Initialise static ringbuffer with a size of size.
@@ -1485,7 +1506,17 @@ void dlt_get_minor_version(char *buf, size_t size);
 /*                                                          */
 
 /**
- * Common part of initialisation
+ * Common part of initialisation. Evaluates the following environment variables
+ * and stores them in dlt_user struct:
+ * - DLT_DISABLE_EXTENDED_HEADER_FOR_NONVERBOSE
+ * - DLT_LOCAL_PRINT_MODE (AUTOMATIC: 0, FORCE_ON: 2, FORCE_OFF: 3)
+ * - DLT_INITIAL_LOG_LEVEL (e.g. APPx:CTXa:6;APPx:CTXb:5)
+ * - DLT_FORCE_BLOCKING
+ * - DLT_USER_BUFFER_MIN
+ * - DLT_USER_BUFFER_MAX
+ * - DLT_USER_BUFFER_STEP
+ * - DLT_LOG_MSG_BUF_LEN
+ * - DLT_DISABLE_INJECTION_MSG_AT_USER
  * @return negative value if there was an error
  */
 DltReturnValue dlt_init_common(void);
@@ -1570,7 +1601,7 @@ DltReturnValue dlt_message_argument_print(DltMessage *msg,
 /**
  * Check environment variables.
  */
-void dlt_check_envvar();
+void dlt_check_envvar(void);
 
 /**
  * Parse the response text and identifying service id and its options.
