@@ -97,16 +97,25 @@
 #include "dlt_client_cfg.h"
 
 static int (*message_callback_function)(DltMessage *message, void *data) = NULL;
+static bool (*fetch_next_message_callback_function)(void *data) = NULL;
 
 void dlt_client_register_message_callback(int (*registerd_callback)(DltMessage *message, void *data))
 {
     message_callback_function = registerd_callback;
 }
 
+void dlt_client_register_fetch_next_message_callback(bool (*registerd_callback)(void *data))
+{
+    fetch_next_message_callback_function = registerd_callback;
+}
+
 DltReturnValue dlt_client_init_port(DltClient *client, int port, int verbose)
 {
     if (verbose && (port != DLT_DAEMON_TCP_PORT))
-        dlt_vlog(LOG_INFO, "Init dlt client struct with port %d\n", port);
+        dlt_vlog(LOG_INFO,
+                 "%s: Init dlt client struct with port %d\n",
+                 __func__,
+                 port);
 
     if (client == NULL)
         return DLT_RETURN_ERROR;
@@ -141,7 +150,8 @@ DltReturnValue dlt_client_init(DltClient *client, int verbose)
 
         if ((tmp_port < IPPORT_RESERVED) || ((unsigned)tmp_port > USHRT_MAX)) {
             dlt_vlog(LOG_ERR,
-                     "Specified port is out of possible range: %d.\n",
+                     "%s: Specified port is out of possible range: %d.\n",
+                     __func__,
                      tmp_port);
             return DLT_RETURN_ERROR;
         }
@@ -152,7 +162,8 @@ DltReturnValue dlt_client_init(DltClient *client, int verbose)
 
     if (verbose)
         dlt_vlog(LOG_INFO,
-                 "Init dlt client struct with default port: %hu.\n",
+                 "%s: Init dlt client struct with default port: %hu.\n",
+                 __func__,
                  servPort);
     return dlt_client_init_port(client, servPort, verbose);
 }
@@ -160,7 +171,6 @@ DltReturnValue dlt_client_init(DltClient *client, int verbose)
 DltReturnValue dlt_client_connect(DltClient *client, int verbose)
 {
     const int yes = 1;
-    int connect_errno = 0;
     char portnumbuffer[33];
     struct addrinfo hints, *servinfo, *p;
     struct sockaddr_un addr;
@@ -179,18 +189,23 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         snprintf(portnumbuffer, 32, "%d", client->port);
 
         if ((rv = getaddrinfo(client->servIP, portnumbuffer, &hints, &servinfo)) != 0) {
-            fprintf(stderr, "getaddrinfo: %s\n", gai_strerror(rv));
+            dlt_vlog(LOG_ERR,
+                    "%s: getaddrinfo: %s\n",
+                     __func__,
+                     gai_strerror(rv));
             return DLT_RETURN_ERROR;
         }
 
         for (p = servinfo; p != NULL; p = p->ai_next) {
             if ((client->sock = socket(p->ai_family, p->ai_socktype, p->ai_protocol)) < 0) {
-                dlt_vlog(LOG_WARNING, "socket() failed! %s\n", strerror(errno));
+                dlt_vlog(LOG_WARNING,
+                         "%s: socket() failed! %s\n",
+                         __func__,
+                         strerror(errno));
                 continue;
             }
 
             if (connect(client->sock, p->ai_addr, p->ai_addrlen) < 0) {
-                connect_errno = errno;
                 close(client->sock);
                 continue;
             }
@@ -201,7 +216,10 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         freeaddrinfo(servinfo);
 
         if (p == NULL) {
-            dlt_vlog(LOG_ERR, "ERROR: failed to connect! %s\n", strerror(connect_errno));
+            dlt_vlog(LOG_INFO,
+                     "%s: Connected to DLT daemon (%s)\n",
+                     __func__,
+                     client->servIP);
             return DLT_RETURN_ERROR;
         }
 
@@ -216,7 +234,10 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         client->sock = open(client->serialDevice, O_RDWR);
 
         if (client->sock < 0) {
-            fprintf(stderr, "ERROR: Failed to open device %s\n", client->serialDevice);
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: Failed to open device %s\n",
+                     __func__,
+                     client->serialDevice);
             return DLT_RETURN_ERROR;
         }
 
@@ -224,8 +245,11 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
             #if !defined (__WIN32__)
 
             if (dlt_setup_serial(client->sock, client->baudrate) < DLT_RETURN_OK) {
-                fprintf(stderr, "ERROR: Failed to configure serial device %s (%s) \n", client->serialDevice,
-                        strerror(errno));
+                dlt_vlog(LOG_ERR,
+                         "%s: ERROR: Failed to configure serial device %s (%s) \n",
+                         __func__,
+                         client->serialDevice,
+                         strerror(errno));
                 return DLT_RETURN_ERROR;
             }
 
@@ -235,16 +259,20 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         }
         else {
             if (verbose)
-                fprintf(stderr,
-                        "ERROR: Device is not a serial device, device = %s (%s) \n",
-                        client->serialDevice,
-                        strerror(errno));
+                dlt_vlog(LOG_ERR,
+                         "%s: ERROR: Device is not a serial device, device = %s (%s) \n",
+                         __func__,
+                         client->serialDevice,
+                         strerror(errno));
 
             return DLT_RETURN_ERROR;
         }
 
         if (verbose)
-            printf("Connected to %s\n", client->serialDevice);
+            dlt_vlog(LOG_INFO,
+                         "%s: Connected to %s\n",
+                         __func__,
+                         client->serialDevice);
 
         receiver_type = DLT_RECEIVE_FD;
 
@@ -252,7 +280,11 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
     case DLT_CLIENT_MODE_UNIX:
 
         if ((client->sock = socket(AF_UNIX, SOCK_STREAM, 0)) == -1) {
-            fprintf(stderr, "ERROR: (unix) socket error: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: (unix) socket error: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
@@ -263,13 +295,20 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         if (connect(client->sock,
                     (struct sockaddr *) &addr,
                     sizeof(addr)) == -1) {
-            fprintf(stderr, "ERROR: (unix) connect error: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: (unix) connect error: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
         if (client->sock < 0) {
-            fprintf(stderr, "ERROR: Failed to open device %s\n",
-                    client->socketPath);
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: Failed to open device %s\n",
+                     __func__,
+                     client->socketPath);
+
             return DLT_RETURN_ERROR;
         }
 
@@ -280,14 +319,22 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
 
         if ((client->sock = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
         {
-            fprintf(stderr, "ERROR: socket error: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: socket error: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
         /* allow multiple sockets to use the same PORT number */
         if (setsockopt(client->sock, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes)) < 0)
         {
-            fprintf(stderr, "ERROR: Reusing address failed: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: Reusing address failed: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
@@ -299,7 +346,11 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         /* bind to receive address */
         if (bind(client->sock, (struct sockaddr*) &client->receiver.addr, sizeof(client->receiver.addr)) < 0)
         {
-            fprintf(stderr, "ERROR: bind failed: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: bind failed: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
@@ -310,20 +361,31 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
         }
         if (client->servIP == NULL)
         {
-            fprintf(stderr, "ERROR: server address not set\n");
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: server address not set\n",
+                     __func__);
+
             return DLT_RETURN_ERROR;
         }
 
         mreq.imr_multiaddr.s_addr = inet_addr(client->servIP);
         if (mreq.imr_multiaddr.s_addr == (in_addr_t)-1)
         {
-            fprintf(stderr, "ERROR: server address not not valid %s\n", client->servIP);
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: server address not not valid %s\n",
+                     __func__,
+                     client->servIP);
+
             return DLT_RETURN_ERROR;
         }
 
         if (setsockopt(client->sock, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&mreq, sizeof(mreq)) < 0)
         {
-            fprintf(stderr, "ERROR: setsockopt add membership failed: %s\n", strerror(errno));
+            dlt_vlog(LOG_ERR,
+                     "%s: ERROR: setsockopt add membership failed: %s\n",
+                     __func__,
+                     strerror(errno));
+
             return DLT_RETURN_ERROR;
         }
 
@@ -331,15 +393,16 @@ DltReturnValue dlt_client_connect(DltClient *client, int verbose)
 
         break;
     default:
-
-        if (verbose)
-            fprintf(stderr, "ERROR: Mode not supported: %d\n", client->mode);
+        dlt_vlog(LOG_ERR,
+                 "%s: ERROR: Mode not supported: %d\n",
+                 __func__,
+                 client->mode);
 
         return DLT_RETURN_ERROR;
     }
 
     if (dlt_receiver_init(&(client->receiver), client->sock, receiver_type, DLT_RECEIVE_BUFSIZE) != DLT_RETURN_OK) {
-        fprintf(stderr, "ERROR initializing receiver\n");
+        dlt_vlog(LOG_ERR, "%s: ERROR initializing receiver\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
@@ -351,7 +414,7 @@ DltReturnValue dlt_client_cleanup(DltClient *client, int verbose)
     int ret = DLT_RETURN_OK;
 
     if (verbose)
-        printf("Cleanup dlt client\n");
+        dlt_vlog(LOG_INFO, "%s: Cleanup dlt client\n", __func__);
 
     if (client == NULL)
         return DLT_RETURN_WRONG_PARAMETER;
@@ -360,8 +423,8 @@ DltReturnValue dlt_client_cleanup(DltClient *client, int verbose)
         close(client->sock);
 
     if (dlt_receiver_free(&(client->receiver)) != DLT_RETURN_OK) {
-        dlt_vlog(LOG_WARNING, "Failed to free receiver\n");
-        ret = DLT_RETURN_ERROR;
+        dlt_vlog(LOG_WARNING, "%s: Failed to free receiver\n", __func__);
+		ret = DLT_RETURN_ERROR;
     }
 
     if (client->serialDevice) {
@@ -397,7 +460,8 @@ DltReturnValue dlt_client_main_loop(DltClient *client, void *data, int verbose)
     if (dlt_message_init(&msg, verbose) == DLT_RETURN_ERROR)
         return DLT_RETURN_ERROR;
 
-    while (1) {
+    bool fetch_next_message = true;
+    while (fetch_next_message) {
         /* wait for data from socket or serial connection */
         ret = dlt_receiver_receive(&(client->receiver));
 
@@ -410,8 +474,10 @@ DltReturnValue dlt_client_main_loop(DltClient *client, void *data, int verbose)
         }
 
         while (dlt_message_read(&msg, (unsigned char *)(client->receiver.buf),
-                                (unsigned int) client->receiver.bytesRcvd, 0,
-                                verbose) == DLT_MESSAGE_ERROR_OK) {
+                                client->receiver.bytesRcvd,
+                                client->resync_serial_header,
+                                verbose) == DLT_MESSAGE_ERROR_OK)
+        {
             /* Call callback function */
             if (message_callback_function)
                 (*message_callback_function)(&msg, data);
@@ -440,6 +506,8 @@ DltReturnValue dlt_client_main_loop(DltClient *client, void *data, int verbose)
             dlt_message_free(&msg, verbose);
             return DLT_RETURN_ERROR;
         }
+        if (fetch_next_message_callback_function)
+          fetch_next_message = (*fetch_next_message_callback_function)(data);
     }
 
     if (dlt_message_free(&msg, verbose) == DLT_RETURN_ERROR)
@@ -448,6 +516,48 @@ DltReturnValue dlt_client_main_loop(DltClient *client, void *data, int verbose)
     return DLT_RETURN_OK;
 }
 
+DltReturnValue dlt_client_send_message_to_socket(DltClient *client, DltMessage *msg)
+{
+    int ret = 0;
+
+    if ((client == NULL) || (client->sock < 0)
+        || (msg == NULL) || (msg->databuffer == NULL))
+    {
+        dlt_log(LOG_ERR, "Invalid parameters\n");
+        return DLT_RETURN_ERROR;
+    }
+
+    if (client->send_serial_header)
+    {
+        ret = send(client->sock, (const char *)dltSerialHeader,
+                   sizeof(dltSerialHeader), 0);
+        if (ret < 0)
+        {
+            dlt_vlog(LOG_ERR, "Sending serial header failed: %s\n",
+                        strerror(errno));
+            return DLT_RETURN_ERROR;
+        }
+    }
+
+    ret = send(client->sock,
+               (const char *)(msg->headerbuffer + sizeof(DltStorageHeader)),
+               msg->headersize - sizeof(DltStorageHeader), 0);
+    if (ret < 0)
+    {
+        dlt_vlog(LOG_ERR, "Sending message header failed: %s\n", strerror(errno));
+        return DLT_RETURN_ERROR;
+    }
+
+    ret = send(client->sock, (const char *)msg->databuffer, msg->datasize, 0);
+    if ( ret < 0)
+    {
+        dlt_vlog(LOG_ERR, "Sending message failed: %s\n", strerror(errno));
+        return DLT_RETURN_ERROR;
+    }
+
+    return DLT_RETURN_OK;
+}
+
 DltReturnValue dlt_client_send_ctrl_msg(DltClient *client, char *apid, char *ctid, uint8_t *payload, uint32_t size)
 {
     DltMessage msg;
@@ -536,8 +646,11 @@ DltReturnValue dlt_client_send_ctrl_msg(DltClient *client, char *apid, char *cti
     len = (int32_t) (msg.headersize - sizeof(DltStorageHeader) + msg.datasize);
 
     if (len > UINT16_MAX) {
-        fprintf(stderr, "Critical: Huge injection message discarded!\n");
-        dlt_message_free(&msg, 0);
+        dlt_vlog(LOG_ERR,
+                 "%s: Critical: Huge injection message discarded!\n",
+                 __func__);
+
+		dlt_message_free(&msg, 0);
 
         return DLT_RETURN_ERROR;
     }
@@ -547,11 +660,21 @@ DltReturnValue dlt_client_send_ctrl_msg(DltClient *client, char *apid, char *cti
     /* Send data (without storage header) */
     if ((client->mode == DLT_CLIENT_MODE_TCP) || (client->mode == DLT_CLIENT_MODE_SERIAL)) {
         /* via FileDescriptor */
+        if (client->send_serial_header)
+        {
+            ret = write(client->sock, dltSerialHeader, sizeof(dltSerialHeader));
+            if (ret < 0)
+            {
+                dlt_log(LOG_ERR, "Sending message failed\n");
+                dlt_message_free(&msg, 0);
+                return DLT_RETURN_ERROR;
+            }
+        }
         ret =
             (int) write(client->sock, msg.headerbuffer + sizeof(DltStorageHeader), msg.headersize - sizeof(DltStorageHeader));
 
         if (0 > ret) {
-            dlt_log(LOG_ERR, "Sending message failed\n");
+            dlt_vlog(LOG_ERR, "%s: Sending message failed\n", __func__);
             dlt_message_free(&msg, 0);
             return DLT_RETURN_ERROR;
         }
@@ -559,7 +682,7 @@ DltReturnValue dlt_client_send_ctrl_msg(DltClient *client, char *apid, char *cti
         ret = (int) write(client->sock, msg.databuffer, msg.datasize);
 
         if (0 > ret) {
-            dlt_log(LOG_ERR, "Sending message failed\n");
+            dlt_vlog(LOG_ERR, "%s: Sending message failed\n", __func__);
             dlt_message_free(&msg, 0);
             return DLT_RETURN_ERROR;
         }
@@ -568,14 +691,18 @@ DltReturnValue dlt_client_send_ctrl_msg(DltClient *client, char *apid, char *cti
         id = DLT_ENDIAN_GET_32(msg.standardheader->htyp, id_tmp);
 
         dlt_vlog(LOG_INFO,
-                 "Control message forwarded : %s\n",
+                 "%s: Control message forwarded : %s\n",
+                 __func__,
                  dlt_get_service_name(id));
     }
     else {
         /* via Socket */
-        send(client->sock, (const char *)(msg.headerbuffer + sizeof(DltStorageHeader)),
-             msg.headersize - sizeof(DltStorageHeader), 0);
-        send(client->sock, (const char *)msg.databuffer, msg.datasize, 0);
+        if (dlt_client_send_message_to_socket(client, &msg) == DLT_RETURN_ERROR)
+        {
+            dlt_log(LOG_ERR, "Sending message to socket failed\n");
+            dlt_message_free(&msg, 0);
+            return DLT_RETURN_ERROR;
+        }
     }
 
     /* free message */
@@ -628,12 +755,11 @@ DltReturnValue dlt_client_send_log_level(DltClient *client, char *apid, char *ct
     if (client == NULL)
         return ret;
 
-    req = (DltServiceSetLogLevel *)malloc(sizeof(DltServiceSetLogLevel));
+    req = calloc(1, sizeof(DltServiceSetLogLevel));
 
     if (req == NULL)
         return ret;
 
-    memset(req, 0, sizeof(DltServiceSetLogLevel));
     req->service_id = DLT_SERVICE_ID_SET_LOG_LEVEL;
     dlt_set_id(req->apid, apid);
     dlt_set_id(req->ctid, ctid);
@@ -739,15 +865,12 @@ DltReturnValue dlt_client_get_software_version(DltClient *client)
 DltReturnValue dlt_client_send_trace_status(DltClient *client, char *apid, char *ctid, uint8_t traceStatus)
 {
     DltServiceSetLogLevel *req;
-    uint8_t *payload;
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetLogLevel));
+    req = calloc(1,sizeof(DltServiceSetLogLevel));
 
-    if (payload == 0)
+    if (req == 0)
         return DLT_RETURN_ERROR;
 
-    req = (DltServiceSetLogLevel *)payload;
-    memset(req, 0, sizeof(DltServiceSetLogLevel));
     req->service_id = DLT_SERVICE_ID_SET_TRACE_STATUS;
     dlt_set_id(req->apid, apid);
     dlt_set_id(req->ctid, ctid);
@@ -755,12 +878,13 @@ DltReturnValue dlt_client_send_trace_status(DltClient *client, char *apid, char
     dlt_set_id(req->com, "remo");
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload, sizeof(DltServiceSetLogLevel)) == DLT_RETURN_ERROR) {
-        free(payload);
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
+                                 sizeof(DltServiceSetLogLevel)) == DLT_RETURN_ERROR) {
+        free(req);
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -768,27 +892,24 @@ DltReturnValue dlt_client_send_trace_status(DltClient *client, char *apid, char
 DltReturnValue dlt_client_send_default_log_level(DltClient *client, uint8_t defaultLogLevel)
 {
     DltServiceSetDefaultLogLevel *req;
-    uint8_t *payload;
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetDefaultLogLevel));
+    req = calloc(1, sizeof(DltServiceSetDefaultLogLevel));
 
-    if (payload == 0)
+    if (req == 0)
         return DLT_RETURN_ERROR;
 
-    req = (DltServiceSetDefaultLogLevel *)payload;
-
     req->service_id = DLT_SERVICE_ID_SET_DEFAULT_LOG_LEVEL;
     req->log_level = defaultLogLevel;
     dlt_set_id(req->com, "remo");
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload,
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
                                  sizeof(DltServiceSetDefaultLogLevel)) == DLT_RETURN_ERROR) {
-        free(payload);
+        free(req);
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -796,26 +917,24 @@ DltReturnValue dlt_client_send_default_log_level(DltClient *client, uint8_t defa
 DltReturnValue dlt_client_send_all_log_level(DltClient *client, uint8_t LogLevel)
 {
     DltServiceSetDefaultLogLevel *req;
-    uint8_t *payload;
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetDefaultLogLevel));
+    req = calloc(1, sizeof(DltServiceSetDefaultLogLevel));
 
-    if (payload == 0)
+    if (req == 0)
         return DLT_RETURN_ERROR;
 
-    req = (DltServiceSetDefaultLogLevel *)payload;
-
     req->service_id = DLT_SERVICE_ID_SET_ALL_LOG_LEVEL;
     req->log_level = LogLevel;
     dlt_set_id(req->com, "remo");
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload, sizeof(DltServiceSetDefaultLogLevel)) == -1) {
-        free(payload);
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
+                                 sizeof(DltServiceSetDefaultLogLevel)) == -1) {
+        free(req);
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -823,27 +942,24 @@ DltReturnValue dlt_client_send_all_log_level(DltClient *client, uint8_t LogLevel
 DltReturnValue dlt_client_send_default_trace_status(DltClient *client, uint8_t defaultTraceStatus)
 {
     DltServiceSetDefaultLogLevel *req;
-    uint8_t *payload;
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetDefaultLogLevel));
+    req = calloc(1, sizeof(DltServiceSetDefaultLogLevel));
 
-    if (payload == 0)
+    if (req == 0)
         return DLT_RETURN_ERROR;
 
-    req = (DltServiceSetDefaultLogLevel *)payload;
-
     req->service_id = DLT_SERVICE_ID_SET_DEFAULT_TRACE_STATUS;
     req->log_level = defaultTraceStatus;
     dlt_set_id(req->com, "remo");
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload,
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
                                  sizeof(DltServiceSetDefaultLogLevel)) == DLT_RETURN_ERROR) {
-        free(payload);
+        free(req);
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -851,33 +967,31 @@ DltReturnValue dlt_client_send_default_trace_status(DltClient *client, uint8_t d
 DltReturnValue dlt_client_send_all_trace_status(DltClient *client, uint8_t traceStatus)
 {
     DltServiceSetDefaultLogLevel *req;
-    uint8_t *payload;
 
     if (client == NULL) {
         dlt_vlog(LOG_ERR, "%s: Invalid parameters\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetDefaultLogLevel));
+    req = calloc(1, sizeof(DltServiceSetDefaultLogLevel));
 
-    if (payload == 0) {
+    if (req == 0) {
         dlt_vlog(LOG_ERR, "%s: Could not allocate memory %zu\n", __func__, sizeof(DltServiceSetDefaultLogLevel));
         return DLT_RETURN_ERROR;
     }
 
-    req = (DltServiceSetDefaultLogLevel *)payload;
-
     req->service_id = DLT_SERVICE_ID_SET_ALL_TRACE_STATUS;
     req->log_level = traceStatus;
     dlt_set_id(req->com, "remo");
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload, sizeof(DltServiceSetDefaultLogLevel)) == -1) {
-        free(payload);
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
+                                 sizeof(DltServiceSetDefaultLogLevel)) == -1) {
+        free(req);;
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -885,25 +999,23 @@ DltReturnValue dlt_client_send_all_trace_status(DltClient *client, uint8_t trace
 DltReturnValue dlt_client_send_timing_pakets(DltClient *client, uint8_t timingPakets)
 {
     DltServiceSetVerboseMode *req;
-    uint8_t *payload;
 
-    payload = (uint8_t *)malloc(sizeof(DltServiceSetVerboseMode));
+    req = calloc(1, sizeof(DltServiceSetVerboseMode));
 
-    if (payload == 0)
+    if (req == 0)
         return DLT_RETURN_ERROR;
 
-    req = (DltServiceSetVerboseMode *)payload;
-
     req->service_id = DLT_SERVICE_ID_SET_TIMING_PACKETS;
     req->new_status = timingPakets;
 
     /* free message */
-    if (dlt_client_send_ctrl_msg(client, "APP", "CON", payload, sizeof(DltServiceSetVerboseMode)) == DLT_RETURN_ERROR) {
-        free(payload);
+    if (dlt_client_send_ctrl_msg(client, "APP", "CON", (uint8_t*) req,
+                                 sizeof(DltServiceSetVerboseMode)) == DLT_RETURN_ERROR) {
+        free(req);
         return DLT_RETURN_ERROR;
     }
 
-    free(payload);
+    free(req);
 
     return DLT_RETURN_OK;
 }
@@ -959,7 +1071,7 @@ int dlt_client_set_server_ip(DltClient *client, char *ipaddr)
     client->servIP = strdup(ipaddr);
 
     if (client->servIP == NULL) {
-        dlt_log(LOG_ERR, "ERROR: failed to duplicate server IP\n");
+        dlt_vlog(LOG_ERR, "%s: ERROR: failed to duplicate server IP\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
@@ -971,7 +1083,7 @@ int dlt_client_set_host_if_address(DltClient *client, char *hostip)
     client->hostip = strdup(hostip);
 
     if (client->hostip == NULL) {
-        dlt_log(LOG_ERR, "ERROR: failed to duplicate UDP interface address\n");
+        dlt_vlog(LOG_ERR, "%s: ERROR: failed to duplicate UDP interface address\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
@@ -983,7 +1095,7 @@ int dlt_client_set_serial_device(DltClient *client, char *serial_device)
     client->serialDevice = strdup(serial_device);
 
     if (client->serialDevice == NULL) {
-        dlt_log(LOG_ERR, "ERROR: failed to duplicate serial device\n");
+        dlt_vlog(LOG_ERR, "%s: ERROR: failed to duplicate serial device\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
@@ -995,7 +1107,7 @@ int dlt_client_set_socket_path(DltClient *client, char *socket_path)
     client->socketPath = strdup(socket_path);
 
     if (client->socketPath == NULL) {
-        dlt_log(LOG_ERR, "ERROR: failed to duplicate socket path\n");
+        dlt_vlog(LOG_ERR, "%s: ERROR: failed to duplicate socket path\n", __func__);
         return DLT_RETURN_ERROR;
     }
 
@@ -1080,15 +1192,18 @@ DltReturnValue dlt_client_parse_get_log_info_resp_text(DltServiceGetLogInfoRespo
         (resp->status > GET_LOG_INFO_STATUS_MAX)) {
         if (resp->status == GET_LOG_INFO_STATUS_NO_MATCHING_CTX)
             dlt_vlog(LOG_WARNING,
-                     "The status(%d) is invalid: NO matching Context IDs\n",
+                     "%s: The status(%d) is invalid: NO matching Context IDs\n",
+                     __func__,
                      resp->status);
         else if (resp->status == GET_LOG_INFO_STATUS_RESP_DATA_OVERFLOW)
             dlt_vlog(LOG_WARNING,
-                     "The status(%d) is invalid: Response data over flow\n",
+                     "%s: The status(%d) is invalid: Response data over flow\n",
+                     __func__,
                      resp->status);
         else
             dlt_vlog(LOG_WARNING,
-                     "The status(%d) is invalid\n",
+                     "%s: The status(%d) is invalid\n",
+                     __func__,
                      resp->status);
 
         return DLT_RETURN_ERROR;
@@ -1102,7 +1217,7 @@ DltReturnValue dlt_client_parse_get_log_info_resp_text(DltServiceGetLogInfoRespo
             (resp->log_info_type.count_app_ids, sizeof(AppIDsType));
 
     if (resp->log_info_type.app_ids == NULL) {
-        dlt_vlog(LOG_ERR, "calloc failed for app_ids\n");
+        dlt_vlog(LOG_ERR, "%s: calloc failed for app_ids\n", __func__);
         dlt_client_free_calloc_failed_get_log_info(resp, 0);
         return DLT_RETURN_ERROR;
     }
@@ -1121,7 +1236,7 @@ DltReturnValue dlt_client_parse_get_log_info_resp_text(DltServiceGetLogInfoRespo
 
         if (app->context_id_info == NULL) {
             dlt_vlog(LOG_ERR,
-                     "calloc failed for context_id_info\n");
+                     "%s: calloc failed for context_id_info\n", __func__);
             dlt_client_free_calloc_failed_get_log_info(resp, i);
             return DLT_RETURN_ERROR;
         }
@@ -1152,7 +1267,7 @@ DltReturnValue dlt_client_parse_get_log_info_resp_text(DltServiceGetLogInfoRespo
                         ((size_t) (con->len_context_description + 1), sizeof(char));
 
                 if (con->context_description == 0) {
-                    dlt_log(LOG_ERR, "calloc failed for context description\n");
+                    dlt_vlog(LOG_ERR, "%s: calloc failed for context description\n", __func__);
                     dlt_client_free_calloc_failed_get_log_info(resp, i);
                     return DLT_RETURN_ERROR;
                 }
@@ -1172,7 +1287,7 @@ DltReturnValue dlt_client_parse_get_log_info_resp_text(DltServiceGetLogInfoRespo
                     ((size_t) (app->len_app_description + 1), sizeof(char));
 
             if (app->app_description == 0) {
-                dlt_log(LOG_ERR, "calloc failed for application description\n");
+                dlt_vlog(LOG_ERR, "%s: calloc failed for application description\n", __func__);
                 dlt_client_free_calloc_failed_get_log_info(resp, i);
                 return DLT_RETURN_ERROR;
             }
