@@ -139,7 +139,8 @@
 #define DLT_USER_ATEXIT_RESEND_BUFFER_SLEEP 100000000
 
 /* Name of environment variable to disable extended header in non verbose mode */
-#define DLT_USER_ENV_DISABLE_EXTENDED_HEADER_FOR_NONVERBOSE "DLT_DISABLE_EXTENDED_HEADER_FOR_NONVERBOSE"
+#define DLT_USER_ENV_DISABLE_EXTENDED_HEADER_FOR_NONVERBOSE \
+    "DLT_DISABLE_EXTENDED_HEADER_FOR_NONVERBOSE"
 
 typedef enum
 {
