@@ -108,7 +108,7 @@ DltReturnValue dlt_user_log_out2(int handle, void *ptr1, size_t len1, void *ptr2
     struct iovec iov[2];
     uint32_t bytes_written;
 
-    if (handle <= 0)
+    if (handle < 0)
         /* Invalid handle */
         return DLT_RETURN_ERROR;
 
@@ -117,7 +117,7 @@ DltReturnValue dlt_user_log_out2(int handle, void *ptr1, size_t len1, void *ptr2
     iov[1].iov_base = ptr2;
     iov[1].iov_len = len2;
 
-    bytes_written = writev(handle, iov, 2);
+    bytes_written = (uint32_t) writev(handle, iov, 2);
 
     if (bytes_written != (len1 + len2))
         return DLT_RETURN_ERROR;
@@ -130,7 +130,7 @@ DltReturnValue dlt_user_log_out3(int handle, void *ptr1, size_t len1, void *ptr2
     struct iovec iov[3];
     uint32_t bytes_written;
 
-    if (handle <= 0)
+    if (handle < 0)
         /* Invalid handle */
         return DLT_RETURN_ERROR;
 
@@ -141,10 +141,15 @@ DltReturnValue dlt_user_log_out3(int handle, void *ptr1, size_t len1, void *ptr2
     iov[2].iov_base = ptr3;
     iov[2].iov_len = len3;
 
-    bytes_written = writev(handle, iov, 3);
+    bytes_written = (uint32_t) writev(handle, iov, 3);
 
     if (bytes_written != (len1 + len2 + len3)) {
         switch (errno) {
+        case ETIMEDOUT:
+        {
+            return DLT_RETURN_PIPE_ERROR;     /* ETIMEDOUT - connect timeout */
+            break;
+        }
         case EBADF:
         {
             return DLT_RETURN_PIPE_ERROR;     /* EBADF - handle not open */
@@ -170,4 +175,4 @@ DltReturnValue dlt_user_log_out3(int handle, void *ptr1, size_t len1, void *ptr2
     }
 
     return DLT_RETURN_OK;
-}
+}
\ No newline at end of file
