@@ -96,6 +96,8 @@ typedef struct
     char *evalue;
     int nvalue;
     int bvalue;
+    int sendSerialHeaderFlag;
+    int resyncSerialHeaderFlag;
 
     char ecuid[4];
     int ohandle;
@@ -141,6 +143,8 @@ void usage()
     printf("  -s            Print DLT messages; only headers\n");
     printf("  -v            Verbose mode\n");
     printf("  -h            Usage\n");
+    printf("  -S            Send message with serial header (Default: Without serial header)\n");
+    printf("  -R            Enable resync serial header\n");
     printf("  -y            Serial device mode\n");
     printf("  -b baudrate   Serial device baudrate (Default: 115200)\n");
     printf("  -e ecuid      Set ECU ID (Default: ECU1)\n");
@@ -173,6 +177,8 @@ int main(int argc, char *argv[])
     dltdata.fvalue = 0;
     dltdata.evalue = 0;
     dltdata.bvalue = 0;
+    dltdata.sendSerialHeaderFlag = 0;
+    dltdata.resyncSerialHeaderFlag = 0;
     dltdata.nvalue = 10000;
     dltdata.ohandle = -1;
 
@@ -199,7 +205,7 @@ int main(int argc, char *argv[])
     /* Fetch command line arguments */
     opterr = 0;
 
-    while ((c = getopt (argc, argv, "vashyxmf:o:e:b:n:")) != -1)
+    while ((c = getopt (argc, argv, "vashSRyxmf:o:e:b:n:")) != -1)
         switch (c) {
         case 'v':
         {
@@ -231,6 +237,16 @@ int main(int argc, char *argv[])
             usage();
             return -1;
         }
+        case 'S':
+        {
+            dltdata.sendSerialHeaderFlag = 1;
+            break;
+        }
+        case 'R':
+        {
+            dltdata.resyncSerialHeaderFlag = 1;
+            break;
+        }
         case 'y':
         {
             dltdata.yflag = 1;
@@ -326,6 +342,10 @@ int main(int argc, char *argv[])
         dlt_client_setbaudrate(&dltclient, dltdata.bvalue);
     }
 
+    /* Update the send and resync serial header flags based on command line option */
+    dltclient.send_serial_header = dltdata.sendSerialHeaderFlag;
+    dltclient.resync_serial_header = dltdata.resyncSerialHeaderFlag;
+
     /* initialise structure to use DLT file */
     dlt_file_init(&(dltdata.file), dltdata.vflag);
 
@@ -447,7 +467,7 @@ int dlt_testclient_message_callback(DltMessage *message, void *data)
                         length_tmp = 0; /* the macro can set this variable to -1 */
 
                         ptr = message->databuffer;
-                        datalength = (int32_t) message->datasize;
+                        datalength = message->datasize;
 
                         /* first read the type info of the first argument: must be string */
                         DLT_MSG_READ_VALUE(type_info_tmp, ptr, datalength, uint32_t);
